==> haskell-hoauth2-2.12.0-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.12.0
visibility:           public
id:                   hoauth2-2.12.0-2IkHC0nAfv35p7O0S0GIuO
key:                  hoauth2-2.12.0-2IkHC0nAfv35p7O0S0GIuO
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  49fd767d06429696a12a82c84e274ed0
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.12.0-2IkHC0nAfv35p7O0S0GIuO
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    base64-1.0-IvjcoFi6kweMiX5bkQHvl binary-0.8.9.1 bytestring-0.11.5.3
    containers-0.6.7 cryptonite-0.30-J05HlVSc5IIHLQ8uVby8as
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR exceptions-0.10.5
    http-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-6VDDo73tyQUDXwOD3Kknnb
    uri-bytestring-aeson-0.1.0.9-FdBgBBeH6mE9DrNbSQ1XEj

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hoauth2-2.13.1-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.13.1
visibility:           public
id:                   hoauth2-2.13.1-G6qXswi1QiXBPjIpxyfD1n
key:                  hoauth2-2.13.1-G6qXswi1QiXBPjIpxyfD1n
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  fee1deff68324783a1c0acd9b5e9635a
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.13.1-G6qXswi1QiXBPjIpxyfD1n
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    base64-1.0-89adjIZRicd5UJyOVzaPU9 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-AGWvxb3uQebCjfbnRIxIRG
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi exceptions-0.10.5
    http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-LdrV5aDMusr3ES1vRzYGGr
    uri-bytestring-aeson-0.1.0.9-84XRrpYBYApEXDkgIStjbz

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
